@@ -24,7 +24,7 @@ def main() -> None:
     """
     from mpi4py import MPI
 
-    MPI.pickle.__init__(
+    MPI.pickle.__init__(  # type: ignore
         cloudpickle.dumps,
         cloudpickle.loads,
         pickle.HIGHEST_PROTOCOL,
@@ -34,16 +34,12 @@ def main() -> None:
     file_name = sys.argv[1]
 
     time_start = time.time()
+    apply_dict = {}
     if mpi_rank_zero:
         apply_dict = backend_load_file(file_name=file_name)
-    else:
-        apply_dict = None
     apply_dict = MPI.COMM_WORLD.bcast(apply_dict, root=0)
     output = apply_dict["fn"].__call__(*apply_dict["args"], **apply_dict["kwargs"])
-    if mpi_size_larger_one:
-        result = MPI.COMM_WORLD.gather(output, root=0)
-    else:
-        result = output
+    result = MPI.COMM_WORLD.gather(output, root=0) if mpi_size_larger_one else output
     if mpi_rank_zero:
         backend_write_file(
             file_name=file_name,
